import axios from 'axios'
import router from '~src/router/index'
import { toSerialize } from 'js-fast-way'

//默认超时时间
axios.defaults.timeout = 0
//返回其他状态码
axios.defaults.validateStatus = function (status) {
    return status >= 200 && status <= 500
}
//跨域请求，允许保存cookie
axios.defaults.withCredentials = true

//http request拦截
axios.interceptors.request.use(config => {
    const meta = (config['meta'] || {})
    //headers中配置text请求
    if (config['text'] === true) {
        config.headers['Content-Type'] = 'text/plain'
    }
    //headers中配置serialize为true开启序列化
    if (config.method === 'post' && meta['isSerialize'] === true) {
        config.data = toSerialize(config.data)
    }
    config.metadata = { startTime: new Date() }
    return config
}, error => {
    return Promise.reject(error)
})

//http response 拦截
axios.interceptors.response.use(res => {
    //响应时间
    res.config.metadata.endTime = new Date()
    //获取状态码
    const status = res?.data?.code || res.status
    //如果是401则跳转到登录页面
    if (status === 401) {
        window.$message?.error('身份失效,请重新登录！')
        router.push({ path: '/login' })
    }
    // 如果请求为非200, 自行catch逻辑处理
    if (status !== 200) {
        return Promise.reject(res)
    }
    return res
}, error => {
    window.$message?.error('请求异常！')
    return Promise.reject(new Error(error))
})

export default axios
